==> miniorange_2fa-8.x-1.0.tar.gz: miniorange_2fa/src/Form/test_qrcode_authentication.php <==
<?php

namespace Drupal\miniorange_2fa\Form;

/**
 * @file
 * Email verification functions.
 */
use Drupal\user\Entity\User;
use Drupal\Core\Form\FormBase;
use Drupal\miniorange_2fa\MiniorangeUser;
use Drupal\miniorange_2fa\MoAuthUtilities;
use Drupal\miniorange_2fa\MoAuthConstants;
use Drupal\miniorange_2fa\AuthenticationType;
use Drupal\Component\Render\FormattableMarkup;
use Drupal\miniorange_2fa\AuthenticationAPIHandler;
use Drupal\miniorange_2fa\MiniorangeCustomerProfile;

/**
 * Menu callback for email verification.
 */
class test_qrcode_authentication extends FormBase
{
    public function getFormId() {
        return 'mo_auth_test_qrcode_authentication';
    }
    public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state)
    {
        $form['markup_top_2'] = array(
            '#markup' => '<div class="mo_saml_table_layout_1"><div class="mo_saml_table_layout mo_saml_container">'
        );

        $form['markup_library'] = array(
            '#attached' => array(
                'library' => array(
                    "miniorange_2fa/miniorange_2fa.admin",
                    "miniorange_2fa/miniorange_2fa.license",
                )
            ),
        );

        global $base_url;
        $url = $base_url . '/admin/config/people/miniorange_2fa/setup_twofactor';
        $input = $form_state->getUserInput();

        $form['actions'] = array('#type' => 'actions');

        if (array_key_exists('txId', $input) === FALSE) {
            $user = User::load(\Drupal::currentUser()->id());
            $user_id = $user->id();
            $utilities = new MoAuthUtilities();
            $custom_attribute = $utilities::get_users_custom_attribute($user_id);
            $user_email = $custom_attribute[0]->miniorange_registered_email;
            $customer = new MiniorangeCustomerProfile();
            $miniorange_user = new MiniorangeUser($customer->getCustomerID(), $user_email, NULL, NULL, AuthenticationType::$QR_CODE['code']);
            $auth_api_handler = new AuthenticationAPIHandler($customer->getCustomerID(), $customer->getAPIKey());
            $response = $auth_api_handler->challenge($miniorange_user);
            if ($response->status == 'SUCCESS') {
                $message = t('Please scan the below QR Code from miniOrange Authenticator app.');
                drupal_set_message($message, 'status');
                $qrCode = $response->qrCode;
                $image = new FormattableMarkup('<img src="data:image/jpg;base64, '.$qrCode.'"/>', [':src' => $qrCode]);
                $form['header']['#markup'] = t(
                    '<div class="mo2f-setup-header">
                                <div class="mo2f-setup-header-top-left">Test QR Code Authentication</div>
                            </div>
                            <div class="mo2f-text-center">
                                 <div class="mo2f-info">Please scan the below QR Code with miniOrange Authenticator app to authenticate yourself.</div>
                                 <div><b>NOTE:</b><i> After scanning below QR code, please wait until page loads automatically.</i></div>'

                );

                $form['actions_qrcode'] = array(
                    '#markup' =>$image
                );

                /* Accessed form mo_authentication.js file */
                $form['txId'] = array(
                    '#type' => 'hidden',
                    '#value' => $response->txId,
                );
                $form['url'] = array(
                    '#type' => 'hidden',
                    '#value' => MoAuthConstants::$AUTH_STATUS_API,
                );

                $form['add_cancel_button'] = array(
                    '#markup' => '<br><a href="'.$url.'">Cancel Test</a>',
                );
            } else {
                $message = 'An error occured while processing your request. Please try again.';
                MoAuthUtilities::show_error_or_success_message($message , 'error');
            }
        }
        $form['actions']['submit'] = array(
            '#type' => 'submit',
            '#value' => t('Test'),
            '#attributes' => array(
                'class' => array(
                    'hidebutton'
                )
            ),
        );

        $form['main_layout_div_end'] = array(
            '#markup' => '<br><br><br><br><br><br><br><br><br><br><br><br></div></div>',
        );

        MoAuthUtilities::AddsupportTab( $form, $form_state);

        return $form;
    }

    /**
     * Form submit handler for email verify.
     */
    public function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {

        $form_state->setRebuild();
        $input = $form_state->getUserInput();
        $txId =$input['txId'];
        $customer = new MiniorangeCustomerProfile();
        $auth_api_handler = new AuthenticationAPIHandler($customer->getCustomerID(), $customer->getAPIKey());
        $response = $auth_api_handler->getAuthStatus($txId);

        // Clear all the messages
        drupal_get_messages();

        // read API response
        if ($response->status == 'SUCCESS') {
            $message = 'You have successfully completed the test.';
            MoAuthUtilities::show_error_or_success_message($message , 'status');
        } elseif ($response->status == 'FAILED') {
            $message = 'Authentication failed.';
            MoAuthUtilities::show_error_or_success_message($message , 'error');
        } else {
            $message = 'An error occured while processing your request. Please try again.';
            MoAuthUtilities::show_error_or_success_message($message , 'error');
        }
    }

    function send_support_query($form, &$form_state) {
        $email = $form['miniorange_2fa_email_address_support']['#value'];
        $phone = $form['miniorange_2fa_phone_number_support']['#value'];
        $query = $form['miniorange_2fa_support_query_support']['#value'];
        MoAuthUtilities::send_support_query($email, $phone, $query);
    }
}

==> miniorange_2fa-8.x-1.1.tar.gz: miniorange_2fa/src/Form/test_qrcode_authentication.php <==
<?php

namespace Drupal\miniorange_2fa\Form;

/**
 * @file
 * Email verification functions.
 */
use Drupal\user\Entity\User;
use Drupal\Core\Form\FormBase;
use Drupal\miniorange_2fa\MiniorangeUser;
use Drupal\miniorange_2fa\MoAuthUtilities;
use Drupal\miniorange_2fa\MoAuthConstants;
use Drupal\miniorange_2fa\AuthenticationType;
use Drupal\Component\Render\FormattableMarkup;
use Drupal\miniorange_2fa\AuthenticationAPIHandler;
use Drupal\miniorange_2fa\MiniorangeCustomerProfile;

/**
 * Menu callback for email verification.
 */
class test_qrcode_authentication extends FormBase
{
    public function getFormId() {
        return 'mo_auth_test_qrcode_authentication';
    }
    public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state)
    {
        $form['markup_top_2'] = array(
            '#markup' => '<div class="mo_saml_table_layout_1"><div class="mo_saml_table_layout mo_saml_container">'
        );

        $form['markup_library'] = array(
            '#attached' => array(
                'library' => array(
                    "miniorange_2fa/miniorange_2fa.admin",
                    "miniorange_2fa/miniorange_2fa.license",
                )
            ),
        );

        global $base_url;
        $url = $base_url . '/admin/config/people/miniorange_2fa/setup_twofactor';
        $input = $form_state->getUserInput();

        $form['actions'] = array('#type' => 'actions');

        if (array_key_exists('txId', $input) === FALSE) {
            $user = User::load(\Drupal::currentUser()->id());
            $user_id = $user->id();
            $utilities = new MoAuthUtilities();
            $custom_attribute = $utilities::get_users_custom_attribute($user_id);
            $user_email = $custom_attribute[0]->miniorange_registered_email;
            $customer = new MiniorangeCustomerProfile();
            $miniorange_user = new MiniorangeUser($customer->getCustomerID(), $user_email, NULL, NULL, AuthenticationType::$QR_CODE['code']);
            $auth_api_handler = new AuthenticationAPIHandler($customer->getCustomerID(), $customer->getAPIKey());
            $response = $auth_api_handler->challenge($miniorange_user);
            if ($response->status == 'SUCCESS') {
                $message = t('Please scan the below QR Code from miniOrange Authenticator app.');
                drupal_set_message($message, 'status');
                $qrCode = $response->qrCode;
                $image = new FormattableMarkup('<img src="data:image/jpg;base64, '.$qrCode.'"/>', [':src' => $qrCode]);
                $form['header']['#markup'] = t(
                    '<div class="mo2f-setup-header">
                                <div class="mo2f-setup-header-top-left">Test QR Code Authentication</div>
                            </div>
                            <div class="mo2f-text-center">
                                 <div class="mo2f-info">Please scan the below QR Code with miniOrange Authenticator app to authenticate yourself.</div>
                                 <div><b><span style="color: red">NOTE:</span></b><i> After scanning below QR code, please wait until page loads automatically.</i></div>'

                );

                $form['actions_qrcode'] = array(
                    '#markup' =>$image
                );

                /* Accessed form mo_authentication.js file */
                $form['txId'] = array(
                    '#type' => 'hidden',
                    '#value' => $response->txId,
                );
                $form['url'] = array(
                    '#type' => 'hidden',
                    '#value' => MoAuthConstants::$AUTH_STATUS_API,
                );

                $form['add_cancel_button'] = array(
                    '#markup' => '<br><a href="'.$url.'">Cancel Test</a>',
                );
            } else {
                $message = 'An error occured while processing your request. Please try again.';
                MoAuthUtilities::show_error_or_success_message($message , 'error');
            }
        }
        $form['actions']['submit'] = array(
            '#type' => 'submit',
            '#value' => t('Test'),
            '#attributes' => array(
                'class' => array(
                    'hidebutton'
                )
            ),
        );

        $form['main_layout_div_end'] = array(
            '#markup' => '<br><br><br><br><br><br><br><br><br><br><br><br></div></div>',
        );

        MoAuthUtilities::AddsupportTab( $form, $form_state);

        return $form;
    }

    /**
     * Form submit handler for email verify.
     */
    public function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {

        $form_state->setRebuild();
        $input = $form_state->getUserInput();
        $txId =$input['txId'];
        $customer = new MiniorangeCustomerProfile();
        $auth_api_handler = new AuthenticationAPIHandler($customer->getCustomerID(), $customer->getAPIKey());
        $response = $auth_api_handler->getAuthStatus($txId);

        // Clear all the messages
        drupal_get_messages();

        // read API response
        if ($response->status == 'SUCCESS') {
            $message = 'You have successfully completed the test.';
            MoAuthUtilities::show_error_or_success_message($message , 'status');
        } elseif ($response->status == 'FAILED') {
            $message = 'Authentication failed.';
            MoAuthUtilities::show_error_or_success_message($message , 'error');
        } else {
            $message = 'An error occured while processing your request. Please try again.';
            MoAuthUtilities::show_error_or_success_message($message , 'error');
        }
    }

    function send_support_query($form, &$form_state) {
        $email = $form['miniorange_2fa_email_address_support']['#value'];
        $phone = $form['miniorange_2fa_phone_number_support']['#value'];
        $query = $form['miniorange_2fa_support_query_support']['#value'];
        MoAuthUtilities::send_support_query($email, $phone, $query);
    }
}
